@@ -4,10 +4,9 @@ import shutil
 import tempfile
 
 from collections import OrderedDict
-from pathlib import Path, PosixPath
+from pathlib import Path, PosixPath, WindowsPath
 from typing import Callable, Union
 
-
 class Anonymize:
 
     def __init__(
@@ -31,11 +30,14 @@ class Anonymize:
         self.mapping_is_function = False
         # if there is no substitution dictionary then convert the csv
         # substitution table into a dictionary
-        if type(mapping) is dict:
+        mapping_type = type(mapping)
+
+        if mapping_type is dict:
             self.mapping = mapping
 
-        elif type(mapping) in [Path, str] :
+        elif mapping_type in [str, Path, PosixPath, WindowsPath]:
             self.mapping = self._convert_csv_to_dict(mapping)
+
         elif callable(mapping):
             # raise an error if the callable is not accompanied by a
             # pattern
@@ -47,7 +49,9 @@ class Anonymize:
                 self.kwargs = kwargs
 
         else:
-            raise TypeError('mapping must be a dictionary, path or function')
+            msg = 'mapping must be a dictionary, path (str, Path, PosixPath, WindowsPath) ' + \
+                f'or function. Found type: {mapping_type}'
+            raise TypeError(msg)
 
         # Word-boundaries: let's add them here, it's a one time 
         # overhead thing. Not the prettiest code.
@@ -82,8 +86,6 @@ class Anonymize:
         # Are we going to make a copy?
         self.copy = False
 
-
-
     def _convert_csv_to_dict(self, path_to_csv: str):
         '''Converts 2-column csv file into dictionary. Left
         column contains ids, right column contains substitutions.
@@ -113,7 +115,6 @@ class Anonymize:
         # return ordered dictionary
         return OrderedDict(data)
 
-
     def _reorder_dict(self):
         '''Re-order the substitution dictionary such that longest keys 
         are processed earlier, regex's come first'''
@@ -124,7 +125,6 @@ class Anonymize:
         )
         self.mapping = OrderedDict(new_dict)
 
-
     def substitute(self, 
         source_path: Union[str, Path], 
         target_path: Union[str, Path]=None
@@ -161,12 +161,9 @@ class Anonymize:
                 # folder doesn't exist, create it
                 self._make_dir(target_path)
 
-            
-
         # start traversing
         self._traverse_tree(source_path, target_path)
 
-
     def _traverse_tree(self, 
         source: Path,
         target: Path
@@ -181,7 +178,6 @@ class Anonymize:
             for child in source.iterdir():
                 self._traverse_tree(child, target)
 
-    
     def _process_folder(self, 
         source: Path,
         target: Path
@@ -203,7 +199,6 @@ class Anonymize:
 
         return result
             
-
     def _process_file(self, 
         source: Path,
         target: Path
@@ -221,7 +216,6 @@ class Anonymize:
         else:
             self._process_unknown_file_type(source, target)
 
-
     def _process_target(
         self,
         source: Path,
@@ -238,7 +232,6 @@ class Anonymize:
             
         return new_target
 
-
     def _process_txt_based_file(
         self,
         source: Path,
@@ -274,6 +267,8 @@ class Anonymize:
         ):
         # create a temp folder to extract to
         with tempfile.TemporaryDirectory() as tmp_folder:
+            # turn folder into Path object
+            tmp_folder = Path(tmp_folder)
             # extract our archive
             shutil.unpack_archive(source, tmp_folder)
             # this is hacky, but inevitable: I want an in-place
@@ -281,6 +276,13 @@ class Anonymize:
             # off and on again
             copy = self.copy
             self.copy = False
+            # this is also a weird one: apparently Mac produces
+            # a MACOSX folder when it zips something, I am 
+            # not interested
+            macosx_folder = (tmp_folder / '__MACOSX')
+            if macosx_folder.exists() and macosx_folder.is_dir():
+                shutil.rmtree(macosx_folder, ignore_errors=True)
+             
             # perform the substitution
             self.substitute(Path(tmp_folder))
             # zip up the substitution
@@ -334,7 +336,7 @@ class Anonymize:
         path.mkdir(parents=True, exist_ok=True)
 
     def _read_file(self, source: Path):
-        f = open(source, 'r', encoding='utf-8')
+        f = open(source, 'r', encoding='utf-8', errors='ignore')
         contents = list(f)
         f.close()
         return contents
@@ -356,4 +358,3 @@ class Anonymize:
     def _copy_file(self, source: Path, target: Path):
         if source != target:
             shutil.copy(source, target)
-
